<?php
// Habilitar la visualización de errores (solo para desarrollo)
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Definir archivo de log en el mismo directorio
$logFile = __DIR__ . '/debug_log.txt';

// Función para registrar mensajes de depuración
function log_debug($message) {
    global $logFile;
    error_log(date('[Y-m-d H:i:s] ') . $message . "\n", 3, $logFile);
}

log_debug("Inicio del script get_trans.php");

// Intentar obtener el header Authorization desde varias fuentes
$authHeader = null;
if (isset($_SERVER['HTTP_AUTHORIZATION'])) {
    $authHeader = $_SERVER['HTTP_AUTHORIZATION'];
    log_debug("HTTP_AUTHORIZATION from _SERVER: " . $authHeader);
} elseif (isset($_SERVER['REDIRECT_HTTP_AUTHORIZATION'])) {
    $authHeader = $_SERVER['REDIRECT_HTTP_AUTHORIZATION'];
    log_debug("REDIRECT_HTTP_AUTHORIZATION from _SERVER: " . $authHeader);
} elseif (function_exists('getallheaders')) {
    $headers = getallheaders();
    log_debug("Headers from getallheaders: " . print_r($headers, true));
    if (isset($headers['Authorization'])) {
        $authHeader = $headers['Authorization'];
        log_debug("Authorization from getallheaders: " . $authHeader);
    }
}

// Cargar el archivo de configuración (config.php)
$configFile = __DIR__ . '/config.php';
if (!file_exists($configFile)) {
    log_debug("Archivo config.php no encontrado.");
    echo json_encode(['success' => false, 'error' => 'Archivo de configuración no encontrado.']);
    exit;
}
$config = require $configFile;
date_default_timezone_set($config['app']['timezone']);

// Verificar la autorización usando el valor definido en config.php
$expectedAuth = "Basic " . $config['auth'];
log_debug("Expected Authorization: " . $expectedAuth);

if (!$authHeader || strcasecmp(trim($authHeader), trim($expectedAuth)) !== 0) {
    http_response_code(401);
    log_debug("Authorization fallido. Header recibido: " . ($authHeader ?? 'nulo'));
    echo json_encode(['success' => false, 'error' => 'Unauthorized']);
    exit;
}
log_debug("Authorization exitosa.");

// Encabezados CORS y Content-Type
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: GET, POST, OPTIONS");
header("Access-Control-Allow-Headers: Content-Type, Authorization");
header("Content-Type: application/json");

// Manejo de preflight OPTIONS
if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    log_debug("Solicitud OPTIONS detectada, saliendo.");
    exit(0);
}

log_debug("Parámetros GET: " . print_r($_GET, true));

try {
    // Conexión a la base de datos usando PDO
    $dsn = 'mysql:host=' . $config['database']['host'] .
           ';dbname=' . $config['database']['dbname'] .
           ';charset=' . $config['database']['charset'];
    $pdo = new PDO($dsn, $config['database']['username'], $config['database']['password']);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    log_debug("Conexión a la BD exitosa.");

    // Construir la consulta según si se pasan parámetros de rango de fecha
    if (isset($_GET['start_date']) && isset($_GET['end_date'])) {
        $start_date = $_GET['start_date'];
        $end_date   = $_GET['end_date'];
        log_debug("Filtrando por fechas: $start_date a $end_date");
        $query = "SELECT * FROM transacciones WHERE fecha BETWEEN :start_date AND :end_date ORDER BY id";
        $stmt = $pdo->prepare($query);
        $stmt->bindParam(':start_date', $start_date);
        $stmt->bindParam(':end_date', $end_date);
    } else {
        log_debug("No se han pasado parámetros de fecha, retornando todos los registros.");
        $query = "SELECT * FROM transacciones ORDER BY id";
        $stmt = $pdo->prepare($query);
    }
    
    log_debug("Consulta: $query");
    
    $stmt->execute();
    $transacciones = $stmt->fetchAll(PDO::FETCH_ASSOC);
    log_debug("Cantidad de registros obtenidos: " . count($transacciones));
    
    // Construir la respuesta en formato JSON
    $response = [
        "success" => true,
        "data" => $transacciones
    ];
    
    echo json_encode($response, JSON_PRETTY_PRINT);
    
} catch (PDOException $e) {
    log_debug("Error en conexión/consulta: " . $e->getMessage());
    echo json_encode(["success" => false, "error" => $e->getMessage()]);
}
?>
